Skip to main content
aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorOlivier Thomann2011-04-06 22:26:04 +0000
committerOlivier Thomann2011-04-06 22:26:04 +0000
commit9ae1051ee3a5e378bfb16bbfa50647f96766ccd2 (patch)
tree79e75028d670d9901a814ab47eda0bd4414c47dc /org.eclipse.jdt.core/compiler/org/eclipse/jdt/internal/compiler/ast/ASTNode.java
parentcd48f3bd12dbe43d04717362699a8ce411f9ff23 (diff)
downloadeclipse.jdt.core-9ae1051ee3a5e378bfb16bbfa50647f96766ccd2.tar.gz
eclipse.jdt.core-9ae1051ee3a5e378bfb16bbfa50647f96766ccd2.tar.xz
eclipse.jdt.core-9ae1051ee3a5e378bfb16bbfa50647f96766ccd2.zip
HEAD - Fixed bug 342054: ILocalVariable#isParameter() returns true for exception of catch clause
Diffstat (limited to 'org.eclipse.jdt.core/compiler/org/eclipse/jdt/internal/compiler/ast/ASTNode.java')
-rw-r--r--org.eclipse.jdt.core/compiler/org/eclipse/jdt/internal/compiler/ast/ASTNode.java5
1 files changed, 4 insertions, 1 deletions
diff --git a/org.eclipse.jdt.core/compiler/org/eclipse/jdt/internal/compiler/ast/ASTNode.java b/org.eclipse.jdt.core/compiler/org/eclipse/jdt/internal/compiler/ast/ASTNode.java
index 2aec02c46e..83415ef2a3 100644
--- a/org.eclipse.jdt.core/compiler/org/eclipse/jdt/internal/compiler/ast/ASTNode.java
+++ b/org.eclipse.jdt.core/compiler/org/eclipse/jdt/internal/compiler/ast/ASTNode.java
@@ -26,7 +26,7 @@ public abstract class ASTNode implements TypeConstants, TypeIds {
// storage for internal flags (32 bits) BIT USAGE
public final static int Bit1 = 0x1; // return type (operator) | name reference kind (name ref) | add assertion (type decl) | useful empty statement (empty statement)
public final static int Bit2 = 0x2; // return type (operator) | name reference kind (name ref) | has local type (type, method, field decl)
- public final static int Bit3 = 0x4; // return type (operator) | name reference kind (name ref) | implicit this (this ref)
+ public final static int Bit3 = 0x4; // return type (operator) | name reference kind (name ref) | implicit this (this ref) | locals (isArgument)
public final static int Bit4 = 0x8; // return type (operator) | first assignment to local (name ref,local decl) | undocumented empty block (block, type and method decl)
public final static int Bit5 = 0x10; // value for return (expression) | has all method bodies (unit) | supertype ref (type ref) | resolved (field decl)
public final static int Bit6 = 0x20; // depth (name ref, msg) | ignore need cast check (cast expression) | error in signature (method declaration/ initializer) | is recovered (annotation reference)
@@ -113,6 +113,9 @@ public abstract class ASTNode implements TypeConstants, TypeIds {
// for name refs or local decls
public static final int FirstAssignmentToLocal = Bit4;
+ // for local decls
+ public static final int IsArgument = Bit3;
+
// for msg or field references
public static final int NeedReceiverGenericCast = Bit19;

Back to the top